==> nostr_dvm-0.9.10-py3-none-any.whl: nostr_dvm/utils/outbox_utils.py <==
# Manual List of known relays we can not write to. It's optional, but this way we avoid
# even trying to send to them, avoiding potential errors or delays on the way.


AVOID_OUTBOX_RELAY_LIST = ["wss://nos.lol",
                           "wss://nostrelay.yeghro.site", "wss://nostr.wine", "wss://filter.nostr.wine",
                           "wss://nostr21.com", "wss://nostr.bitcoiner.social", "wss://nostr.orangepill.dev",
                           "wss://brb.io",
                           "wss://relay.lnpay.me", "wss://relay.snort.social", "wss://relay.minds.com/nostr/v1/ws",
                           "ws://elitedesk:4848",
                           "wss://nostr-pub.semisol.dev", "wss://mostr.mostr.pub", "wss://relay.mostr.pub",
                           "wss://minds.com",
                           "wss://yabu.me", "wss://relay.yozora.world", "wss://filter.nostr.wine/?global=all",
                           "wss://eden.nostr.land",
                           "wss://relay.orangepill.ovh", "wss://nostr.jcloud.es", "wss://af.purplerelay.com",
                           "wss://za.purplerelay.com",
                           "wss://relay.nostrich.land", "wss://relay.nostrplebs.com", "wss://relay.nostrich.land",
                           "ws://elitedesk.local:4848",
                           "wss://rss.nos.social", "wss://atlas.nostr.land", "wss://puravida.nostr.land",
                           "wss://nostr.inosta.cc",
                           "wss://relay.orangepill.dev", "wss://no.str.cr", "wss://nostr.milou.lol",
                           "wss://relay.nostr.com.au",
                           "wss://puravida.nostr.land", "wss://atlas.nostr.land", "wss://nostr-pub.wellorder.net",
                           "wss://relay.current.fyi",
                           "wss://nostr.thesamecat.io", "wss://nostr.plebchain.org", "wss://relay.noswhere.com",
                           "wss://nostr.uselessshit.co",
                           "wss://bitcoiner.social", "wss://relay.stoner.com", "wss://nostr.l00p.org",
                           "wss://relay.nostr.ro", "wss://nostr.kollider.xyz",
                           "wss://relay.valera.co", "wss://relay.austrich.net", "wss://relay.nostrich.de",
                           "wss://nostr.azte.co", "wss://nostr-relay.schnitzel.world",
                           "wss://relay.nostriches.org", "wss://happytavern.co", "wss://onlynotes.lol",
                           "wss://offchain.pub", "wss://purplepag.es", "wss://relay.plebstr.com",
                           "wss://poster.place/relay", "wss://relayable.org", "wss://bbb.santos.lol",
                           "wss://relay.bitheaven.social", "wss://theforest.nostr1.com", "wss://at.nostrworks.com",
                           "wss://relay.nostrati.com", "wss://purplerelay.com", "wss://hist.nostr.land",
                           "wss://creatr.nostr.wine", "ws://localhost:4869", "wss://pleb.cloud",
                           "wss://pyramid.fiatjaf.com", "wss://relay.nos.social", "wss://nostr.thank.eu",
                           "wss://inbox.nostr.wine", "wss://relay.pleb.to", "wss://welcome.nostr.wine",
                           "wss://relay.nostrview.com", "wss://nostr.land", "wss://eu.purplerelay.com",
                           "wss://xmr.usenostr.org", "wss://nostr-relay.app", "ws://umbrel:4848", "wss://umbrel:4848",
                           "wss://fiatjaf.com", "wss://nostr-relay.wlvs.space", "wss://relayer.fiatjaf.com",
                           "wss://nostr.yuv.al", "wss://relay.nostr.band", "wss://nostr.massmux.com",
                           "wss://nostr-01.bolt.observer", "wss://nostr1.tunnelsats.com", "wss://relay.nostr.ch",
                           "wss://relay.nostr.io", "wss://nostr.thank.eu", "wss://nostr.bitcoinplebs.de",
                           "wss://adult.18plus.social", "wss://bostr.online", "wss://relay.current.fyi",
                           "wss://nosdrive.app/relay", "wss://studio314.nostr1.com", "wss://relay.nostrbr.online",
                           "wss://relay.0xchat.com", "wss://lightning.benchodroff.com/nostrclient/api/v1/relay",
                           "wss://relay.nostreggs.io", "wss://relay.blackbyte.nl", "ws://localhost:8080", "wss://127.0.0.1:4869", "wss://sendit.nosflare.io",
                           "wss://astral.ninja", "wss://nostr.libertasprimordium.com", "wss://relay.shitforce.one", "wss://nostr.cro.social",
                           "wss://relay.nostreggs.io", "wss://nostr.rocks", "wss://groups.0xchat.com", "wss://bostr.lecturify.net", "wss://dave.st.germa.in/nostr",
                           "wss://dvms.f7z.io", "wss://nostr.social", "wss://i.nostr.build", "wss://teemie1-relay.duckdns.org",
                           "wss://nostrs.build", "wss://relay.hllo.live", "wss://relay-pub.deschooling.us", "wss://nostr.sandwich.farm", "wss://nostr.lol", "wss://nostr.developer.li",
                           "wss://paid.spore.ws", "'ws://ofotwjuiv7t6q4azt2fjx3qo7esglmxdeqmh2qvdsdnxw5eqgza24iyd.onion", "wss://r.kojira.io", "wss://nostr-relay.h3z.jp", "wss://relay.yozora.world",
                           "wss://nostr.0xtr.dev", "wss://purplepeg.es", "wss://nostr.mutinywallet.com", "wss://nostr.zebedee.cloud", "wss://relay.wikifreedia.xyz", "wss://relay.exit.pub",
                           "wss://njump.mecheck", "wss://relay.nostr.band", "wss://nostr.kollider.xyz", "wss://fog.dedyn.io", "wss://relay.current.fyi",
                           "wss://momostr.pink", "wss://nostr.bitcoinlighthouse.de", "wss://140.f7z.io"

                           ]

==> nostr_dvm-0.9.11-py3-none-any.whl: nostr_dvm/utils/outbox_utils.py <==
# Manual List of known relays we can not write to. It's optional, but this way we avoid
# even trying to send to them, avoiding potential errors or delays on the way.


AVOID_OUTBOX_RELAY_LIST = ["wss://nos.lol",
                           "wss://nostrelay.yeghro.site", "wss://nostr.wine", "wss://filter.nostr.wine",
                           "wss://nostr21.com", "wss://nostr.bitcoiner.social", "wss://nostr.orangepill.dev",
                           "wss://brb.io",
                           "wss://relay.lnpay.me", "wss://relay.snort.social", "wss://relay.minds.com/nostr/v1/ws",
                           "ws://elitedesk:4848",
                           "wss://nostr-pub.semisol.dev", "wss://mostr.mostr.pub", "wss://relay.mostr.pub",
                           "wss://minds.com",
                           "wss://yabu.me", "wss://relay.yozora.world", "wss://filter.nostr.wine/?global=all",
                           "wss://eden.nostr.land",
                           "wss://relay.orangepill.ovh", "wss://nostr.jcloud.es", "wss://af.purplerelay.com",
                           "wss://za.purplerelay.com",
                           "wss://relay.nostrich.land", "wss://relay.nostrplebs.com", "wss://relay.nostrich.land",
                           "ws://elitedesk.local:4848",
                           "wss://rss.nos.social", "wss://atlas.nostr.land", "wss://puravida.nostr.land",
                           "wss://nostr.inosta.cc",
                           "wss://relay.orangepill.dev", "wss://no.str.cr", "wss://nostr.milou.lol",
                           "wss://relay.nostr.com.au",
                           "wss://puravida.nostr.land", "wss://atlas.nostr.land", "wss://nostr-pub.wellorder.net",
                           "wss://relay.current.fyi",
                           "wss://nostr.thesamecat.io", "wss://nostr.plebchain.org", "wss://relay.noswhere.com",
                           "wss://nostr.uselessshit.co",
                           "wss://bitcoiner.social", "wss://relay.stoner.com", "wss://nostr.l00p.org",
                           "wss://relay.nostr.ro", "wss://nostr.kollider.xyz",
                           "wss://relay.valera.co", "wss://relay.austrich.net", "wss://relay.nostrich.de",
                           "wss://nostr.azte.co", "wss://nostr-relay.schnitzel.world",
                           "wss://relay.nostriches.org", "wss://happytavern.co", "wss://onlynotes.lol",
                           "wss://offchain.pub", "wss://purplepag.es", "wss://relay.plebstr.com",
                           "wss://poster.place/relay", "wss://relayable.org", "wss://bbb.santos.lol",
                           "wss://relay.bitheaven.social", "wss://theforest.nostr1.com", "wss://at.nostrworks.com",
                           "wss://relay.nostrati.com", "wss://purplerelay.com", "wss://hist.nostr.land",
                           "wss://creatr.nostr.wine", "ws://localhost:4869", "wss://pleb.cloud",
                           "wss://pyramid.fiatjaf.com", "wss://relay.nos.social", "wss://nostr.thank.eu",
                           "wss://inbox.nostr.wine", "wss://relay.pleb.to", "wss://welcome.nostr.wine",
                           "wss://relay.nostrview.com", "wss://nostr.land", "wss://eu.purplerelay.com",
                           "wss://xmr.usenostr.org", "wss://nostr-relay.app", "ws://umbrel:4848", "wss://umbrel:4848",
                           "wss://fiatjaf.com", "wss://nostr-relay.wlvs.space", "wss://relayer.fiatjaf.com",
                           "wss://nostr.yuv.al", "wss://relay.nostr.band", "wss://nostr.massmux.com",
                           "wss://nostr-01.bolt.observer", "wss://nostr1.tunnelsats.com", "wss://relay.nostr.ch",
                           "wss://relay.nostr.io", "wss://nostr.thank.eu", "wss://nostr.bitcoinplebs.de",
                           "wss://adult.18plus.social", "wss://bostr.online", "wss://relay.current.fyi",
                           "wss://nosdrive.app/relay", "wss://studio314.nostr1.com", "wss://relay.nostrbr.online",
                           "wss://relay.0xchat.com", "wss://lightning.benchodroff.com/nostrclient/api/v1/relay",
                           "wss://relay.nostreggs.io", "wss://relay.blackbyte.nl", "ws://localhost:8080",
                           "wss://127.0.0.1:4869", "wss://sendit.nosflare.io",
                           "wss://astral.ninja", "wss://nostr.libertasprimordium.com", "wss://relay.shitforce.one",
                           "wss://nostr.cro.social",
                           "wss://relay.nostreggs.io", "wss://nostr.rocks", "wss://groups.0xchat.com",
                           "wss://bostr.lecturify.net", "wss://dave.st.germa.in/nostr",
                           "wss://dvms.f7z.io", "wss://nostr.social", "wss://i.nostr.build",
                           "wss://teemie1-relay.duckdns.org",
                           "wss://nostrs.build", "wss://relay.hllo.live", "wss://relay-pub.deschooling.us",
                           "wss://nostr.sandwich.farm", "wss://nostr.lol", "wss://nostr.developer.li",
                           "wss://paid.spore.ws",
                           "ws://ofotwjuiv7t6q4azt2fjx3qo7esglmxdeqmh2qvdsdnxw5eqgza24iyd.onion", "wss://r.kojira.io",
                           "wss://nostr-relay.h3z.jp", "wss://relay.yozora.world",
                           "wss://nostr.0xtr.dev", "wss://purplepeg.es", "wss://nostr.mutinywallet.com",
                           "wss://nostr.zebedee.cloud", "wss://relay.wikifreedia.xyz", "wss://relay.exit.pub",
                           "wss://njump.mecheck", "wss://relay.nostr.band", "wss://nostr.kollider.xyz",
                           "wss://fog.dedyn.io", "wss://relay.current.fyi",
                           "wss://momostr.pink", "wss://nostr.bitcoinlighthouse.de", "wss://140.f7z.io",
                           "wss://relay.nostrcheck.me", "wss://relay.mostr.pub", "wss://purplepag.es",
                           "wss://nostr.bitcoiner.social", "wss://relay.galtsgulch.cc",
                           "ws://oxtrdevav64z64yb7x6rjg4ntzqjhedm5b5zjqulugknhzr46ny2qbad.onion",
                           "wss://relay.f7z.io", "wss://nostr-relay.h3z.jp", "wss://nfrelay.app",
                           "wss://r.kojira.io"

                           ]
